pub struct NormalBorderData {
pub border: NormalBorder,
pub widths: LayoutSideOffsets,
}Fields
border: NormalBorderwidths: LayoutSideOffsetsImplementations
Sourceimpl NormalBorderData
impl NormalBorderData
Sourcepub fn write_brush_gpu_blocks(
&mut self,
common: &mut PrimTemplateCommonData,
prim_size: LayoutSize,
brush_segments: &[BrushSegment],
frame_state: &mut FrameBuildingState<'_>,
) -> GpuBufferAddress
pub fn write_brush_gpu_blocks( &mut self, common: &mut PrimTemplateCommonData, prim_size: LayoutSize, brush_segments: &[BrushSegment], frame_state: &mut FrameBuildingState<'_>, ) -> GpuBufferAddress
Update the GPU cache for a given primitive template. This may be called multiple times per frame, by each primitive reference that refers to this interned template. The initial request call to the GPU cache ensures that work is only done if the cache entry is invalid (due to first use or eviction).
pub fn update( &mut self, border_segments: &[BorderSegmentInfo], prim_spatial_node_index: SpatialNodeIndex, device_pixel_scale: DevicePixelScale, frame_context: &FrameBuildingContext<'_>, frame_state: &mut FrameBuildingState<'_>, task_ids: &mut [RenderTaskId], )